@@ -331,7 +331,7 @@ def load_data(connector, batch, separate_good_object_id, object_id_delimiter, ma
     temp_batch = batch
 
     # each batch is approximately 10 MB, so we divide the total desired file size by that
-    total_batches = math.ceil((size * GB) / 10 * MB)
+    total_batches = math.ceil((size * GB) / (10 * MB))
     memory_bytes = sys.getsizeof(temp_batch)
 
     start = time.time()
@@ -342,30 +342,31 @@ def load_data(connector, batch, separate_good_object_id, object_id_delimiter, ma
     while batch_number <= total_batches:
         rows_loaded += len(temp_batch)
         print(f"Batch {batch_number}/{total_batches}: Loaded {rows_loaded} rows out of {total_batches * batch_rows} "
-              f"in {elapsed_time} seconds. \nCurrent size in memory: {memory_bytes / MB} MB.")
+              f"in {elapsed_time} seconds.")
         batch_number += 1
 
         temp_batch = batch
-        memory_bytes = sys.getsizeof(temp_batch)
+        if memory_bytes < sys.getsizeof(temp_batch):
+            memory_bytes = sys.getsizeof(temp_batch)
         start = time.time()
         connector.load_data(temp_batch, object_id, mapping_object, _replace, batch_number, total_batches)
         end = time.time()
         elapsed_time += (end - start)
 
     print(f"Loaded {rows_loaded} rows out of {total_batches * batch_rows}."
-          f"\nTotal size uploaded: {size} GB.")
+          f"\nTotal size uploaded: {size} GB. \nLargest size in memory: {memory_bytes / MB} MB.")
     with open("load_test_results.txt", "a") as f:
-        f.write(f"LoadTest for {size} GB")
-        f.write(f"Loaded {rows_loaded} rows out of {total_batches * batch_rows}."
-                f"\nTotal size uploaded: {size} GB.\n")
+        f.write(f"\nLoadTest for {size} GB")
+        f.write(f"\nLoaded {rows_loaded} rows out of {total_batches * batch_rows}."
+                f"\nLargest size in memory: {memory_bytes / MB} MB.")
 
         hours = math.floor(elapsed_time / (60. * 60.))
         minutes = math.floor((elapsed_time % (60. * 60.)) / 60.)
         seconds = (elapsed_time % (60. * 60.)) % 60.
         formatted_time = f"{hours} Hours {minutes} Minutes and {seconds} Seconds"
 
-        print(f"Time elapsed to load {num_gigs} GB: {formatted_time}.")
-        f.write(f"Time elapsed to load {num_gigs} GB: {formatted_time}.")
+        print(f"\nTime elapsed to load {num_gigs} GB: {formatted_time}.\n")
+        f.write(f"\nTime elapsed to load {num_gigs} GB: {formatted_time}.\n")
         return True
 
 
